@@ -24,6 +24,7 @@ from .literals import (
     ConfigurationStateType,
     EnhancedMonitoringType,
     KafkaVersionStatusType,
+    StorageModeType,
 )
 
 if sys.version_info >= (3, 9):
@@ -110,10 +111,12 @@ __all__ = (
     "UpdateConnectivityResponseTypeDef",
     "UpdateMonitoringResponseTypeDef",
     "UpdateSecurityResponseTypeDef",
+    "UpdateStorageResponseTypeDef",
     "BatchAssociateScramSecretResponseTypeDef",
     "BatchDisassociateScramSecretResponseTypeDef",
     "BrokerEBSVolumeInfoTypeDef",
     "EBSStorageInfoTypeDef",
+    "UpdateStorageRequestRequestTypeDef",
     "BrokerLogsTypeDef",
     "BrokerNodeInfoTypeDef",
     "ClusterOperationStepTypeDef",
@@ -960,6 +963,15 @@ UpdateSecurityResponseTypeDef = TypedDict(
     },
 )
 
+UpdateStorageResponseTypeDef = TypedDict(
+    "UpdateStorageResponseTypeDef",
+    {
+        "ClusterArn": str,
+        "ClusterOperationArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 BatchAssociateScramSecretResponseTypeDef = TypedDict(
     "BatchAssociateScramSecretResponseTypeDef",
     {
@@ -1009,6 +1021,30 @@ EBSStorageInfoTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredUpdateStorageRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateStorageRequestRequestTypeDef",
+    {
+        "ClusterArn": str,
+        "CurrentVersion": str,
+    },
+)
+_OptionalUpdateStorageRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateStorageRequestRequestTypeDef",
+    {
+        "ProvisionedThroughput": ProvisionedThroughputTypeDef,
+        "StorageMode": StorageModeType,
+        "VolumeSizeGB": int,
+    },
+    total=False,
+)
+
+
+class UpdateStorageRequestRequestTypeDef(
+    _RequiredUpdateStorageRequestRequestTypeDef, _OptionalUpdateStorageRequestRequestTypeDef
+):
+    pass
+
+
 BrokerLogsTypeDef = TypedDict(
     "BrokerLogsTypeDef",
     {
@@ -1522,6 +1558,7 @@ MutableClusterInfoTypeDef = TypedDict(
         "ClientAuthentication": ClientAuthenticationTypeDef,
         "EncryptionInfo": EncryptionInfoTypeDef,
         "ConnectivityInfo": ConnectivityInfoTypeDef,
+        "StorageMode": StorageModeType,
     },
     total=False,
 )
@@ -1570,6 +1607,7 @@ ClusterInfoTypeDef = TypedDict(
         "Tags": Dict[str, str],
         "ZookeeperConnectString": str,
         "ZookeeperConnectStringTls": str,
+        "StorageMode": StorageModeType,
     },
     total=False,
 )
@@ -1593,6 +1631,7 @@ _OptionalCreateClusterRequestRequestTypeDef = TypedDict(
         "OpenMonitoring": OpenMonitoringInfoTypeDef,
         "LoggingInfo": LoggingInfoTypeDef,
         "Tags": Mapping[str, str],
+        "StorageMode": StorageModeType,
     },
     total=False,
 )
@@ -1621,6 +1660,7 @@ _OptionalProvisionedRequestTypeDef = TypedDict(
         "EnhancedMonitoring": EnhancedMonitoringType,
         "OpenMonitoring": OpenMonitoringInfoTypeDef,
         "LoggingInfo": LoggingInfoTypeDef,
+        "StorageMode": StorageModeType,
     },
     total=False,
 )
@@ -1650,6 +1690,7 @@ _OptionalProvisionedTypeDef = TypedDict(
         "LoggingInfo": LoggingInfoTypeDef,
         "ZookeeperConnectString": str,
         "ZookeeperConnectStringTls": str,
+        "StorageMode": StorageModeType,
     },
     total=False,
 )
